pub struct DriversLicense {
pub first_name: Option<EncString>,
pub middle_name: Option<EncString>,
pub last_name: Option<EncString>,
pub date_of_birth: Option<EncString>,
pub license_number: Option<EncString>,
pub issuing_country: Option<EncString>,
pub issuing_state: Option<EncString>,
pub issue_date: Option<EncString>,
pub expiration_date: Option<EncString>,
pub issuing_authority: Option<EncString>,
pub license_class: Option<EncString>,
}Fields
first_name: Option<EncString>middle_name: Option<EncString>last_name: Option<EncString>date_of_birth: Option<EncString>license_number: Option<EncString>issuing_country: Option<EncString>issuing_state: Option<EncString>issue_date: Option<EncString>expiration_date: Option<EncString>license_class: Option<EncString>Trait Implementations
Sourceimpl CipherKind for DriversLicense
impl CipherKind for DriversLicense
Sourcefn decrypt_subtitle(
&self,
ctx: &mut KeyStoreContext<'_, KeySlotIds>,
key: SymmetricKeySlotId,
) -> Result<String, CryptoError>
fn decrypt_subtitle( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<String, CryptoError>
Returns the item’s subtitle.
Sourcefn get_copyable_fields(&self, _: Option<&Cipher>) -> Vec<CopyableCipherFields>
fn get_copyable_fields(&self, _: Option<&Cipher>) -> Vec<CopyableCipherFields>
Returns a list of populated fields for the cipher.
Sourceimpl Clone for DriversLicense
impl Clone for DriversLicense
Sourcefn clone(&self) -> DriversLicense
fn clone(&self) -> DriversLicense
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, DriversLicense> for DriversLicenseView
impl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, DriversLicense> for DriversLicenseView
Sourcefn encrypt_composite(
&self,
ctx: &mut KeyStoreContext<'_, KeySlotIds>,
key: SymmetricKeySlotId,
) -> Result<DriversLicense, CryptoError>
fn encrypt_composite( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<DriversLicense, CryptoError>
⚠️ IMPORTANT NOTE ⚠️ Read more
Sourceimpl<UT> ConvertError<UT> for DriversLicense
impl<UT> ConvertError<UT> for DriversLicense
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for DriversLicense
impl Debug for DriversLicense
Sourceimpl Decryptable<KeySlotIds, SymmetricKeySlotId, DriversLicenseView> for DriversLicense
impl Decryptable<KeySlotIds, SymmetricKeySlotId, DriversLicenseView> for DriversLicense
fn decrypt( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<DriversLicenseView, CryptoError>
Sourceimpl<'de> Deserialize<'de> for DriversLicense
impl<'de> Deserialize<'de> for DriversLicense
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for DriversLicense
impl<UT> FfiConverter<UT> for DriversLicense
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<DriversLicense> for CipherDriversLicenseModel
impl From<DriversLicense> for CipherDriversLicenseModel
Sourcefn from(dl: DriversLicense) -> Self
fn from(dl: DriversLicense) -> Self
Converts to this type from the input type.
Sourceimpl From<DriversLicense> for JsValuewhere
DriversLicense: Serialize,
impl From<DriversLicense> for JsValuewhere
DriversLicense: Serialize,
Sourcefn from(value: DriversLicense) -> Self
fn from(value: DriversLicense) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for DriversLicensewhere
Self: DeserializeOwned,
impl FromWasmAbi for DriversLicensewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &DriversLicensewhere
DriversLicense: Serialize,
impl IntoWasmAbi for &DriversLicensewhere
DriversLicense: Serialize,
Sourceimpl IntoWasmAbi for DriversLicensewhere
DriversLicense: Serialize,
impl IntoWasmAbi for DriversLicensewhere
DriversLicense: Serialize,
Sourceimpl<UT> Lift<UT> for DriversLicense
impl<UT> Lift<UT> for DriversLicense
Sourceimpl<UT> LiftRef<UT> for DriversLicense
impl<UT> LiftRef<UT> for DriversLicense
type LiftType = DriversLicense
Sourceimpl<UT> LiftReturn<UT> for DriversLicense
impl<UT> LiftReturn<UT> for DriversLicense
Sourcetype ReturnType = <DriversLicense as Lift<UT>>::FfiType
type ReturnType = <DriversLicense as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for DriversLicense
impl<UT> Lower<UT> for DriversLicense
Sourceimpl<UT> LowerError<UT> for DriversLicense
impl<UT> LowerError<UT> for DriversLicense
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for DriversLicense
impl<UT> LowerReturn<UT> for DriversLicense
Sourcetype ReturnType = <DriversLicense as Lower<UT>>::FfiType
type ReturnType = <DriversLicense as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for DriversLicensewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for DriversLicensewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for DriversLicensewhere
DriversLicense: Serialize,
impl OptionIntoWasmAbi for DriversLicensewhere
DriversLicense: Serialize,
Sourceimpl RefFromWasmAbi for DriversLicensewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for DriversLicensewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<DriversLicense>
type Anchor = SelfOwner<DriversLicense>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for DriversLicense
impl Serialize for DriversLicense
Sourceimpl TryFrom<CipherDriversLicenseModel> for DriversLicense
impl TryFrom<CipherDriversLicenseModel> for DriversLicense
Sourceimpl Tsify for DriversLicense
impl Tsify for DriversLicense
const DECL: &'static str = "export interface DriversLicense {\n firstName: EncString | undefined;\n middleName: EncString | undefined;\n lastName: EncString | undefined;\n dateOfBirth: EncString | undefined;\n licenseNumber: EncString | undefined;\n issuingCountry: EncString | undefined;\n issuingState: EncString | undefined;\n issueDate: EncString | undefined;\n expirationDate: EncString | undefined;\n issuingAuthority: EncString | undefined;\n licenseClass: EncString | undefined;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for DriversLicense
impl<UT> TypeId<UT> for DriversLicense
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorFromWasmAbi for DriversLicensewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for DriversLicensewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for DriversLicensewhere
DriversLicense: Serialize,
impl VectorIntoWasmAbi for DriversLicensewhere
DriversLicense: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for DriversLicense
impl WasmDescribe for DriversLicense