pub struct DriversLicenseView {
pub first_name: Option<String>,
pub middle_name: Option<String>,
pub last_name: Option<String>,
pub date_of_birth: Option<String>,
pub license_number: Option<String>,
pub issuing_country: Option<String>,
pub issuing_state: Option<String>,
pub issue_date: Option<String>,
pub expiration_date: Option<String>,
pub issuing_authority: Option<String>,
pub license_class: Option<String>,
}Fields
first_name: Option<String>middle_name: Option<String>last_name: Option<String>date_of_birth: Option<String>license_number: Option<String>issuing_country: Option<String>issuing_state: Option<String>issue_date: Option<String>expiration_date: Option<String>license_class: Option<String>Trait Implementations
Sourceimpl Clone for DriversLicenseView
impl Clone for DriversLicenseView
Sourcefn clone(&self) -> DriversLicenseView
fn clone(&self) -> DriversLicenseView
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, DriversLicense> for DriversLicenseView
impl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, DriversLicense> for DriversLicenseView
Sourcefn encrypt_composite(
&self,
ctx: &mut KeyStoreContext<'_, KeySlotIds>,
key: SymmetricKeySlotId,
) -> Result<DriversLicense, CryptoError>
fn encrypt_composite( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<DriversLicense, CryptoError>
⚠️ IMPORTANT NOTE ⚠️ Read more
Sourceimpl<UT> ConvertError<UT> for DriversLicenseView
impl<UT> ConvertError<UT> for DriversLicenseView
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for DriversLicenseView
impl Debug for DriversLicenseView
Sourceimpl Decryptable<KeySlotIds, SymmetricKeySlotId, DriversLicenseView> for DriversLicense
impl Decryptable<KeySlotIds, SymmetricKeySlotId, DriversLicenseView> for DriversLicense
fn decrypt( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<DriversLicenseView, CryptoError>
Sourceimpl Default for DriversLicenseView
impl Default for DriversLicenseView
Sourcefn default() -> DriversLicenseView
fn default() -> DriversLicenseView
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DriversLicenseView
impl<'de> Deserialize<'de> for DriversLicenseView
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for DriversLicenseView
impl<UT> FfiConverter<UT> for DriversLicenseView
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<&DriversLicenseDataV1> for DriversLicenseView
impl From<&DriversLicenseDataV1> for DriversLicenseView
Sourcefn from(src: &DriversLicenseDataV1) -> Self
fn from(src: &DriversLicenseDataV1) -> Self
Converts to this type from the input type.
Sourceimpl From<&DriversLicenseView> for DriversLicenseDataV1
impl From<&DriversLicenseView> for DriversLicenseDataV1
Sourcefn from(src: &DriversLicenseView) -> Self
fn from(src: &DriversLicenseView) -> Self
Converts to this type from the input type.
Sourceimpl From<DriversLicenseView> for JsValuewhere
DriversLicenseView: Serialize,
impl From<DriversLicenseView> for JsValuewhere
DriversLicenseView: Serialize,
Sourcefn from(value: DriversLicenseView) -> Self
fn from(value: DriversLicenseView) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for DriversLicenseViewwhere
Self: DeserializeOwned,
impl FromWasmAbi for DriversLicenseViewwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &DriversLicenseViewwhere
DriversLicenseView: Serialize,
impl IntoWasmAbi for &DriversLicenseViewwhere
DriversLicenseView: Serialize,
Sourceimpl IntoWasmAbi for DriversLicenseViewwhere
DriversLicenseView: Serialize,
impl IntoWasmAbi for DriversLicenseViewwhere
DriversLicenseView: Serialize,
Sourceimpl<UT> Lift<UT> for DriversLicenseView
impl<UT> Lift<UT> for DriversLicenseView
Sourceimpl<UT> LiftRef<UT> for DriversLicenseView
impl<UT> LiftRef<UT> for DriversLicenseView
Sourceimpl<UT> LiftReturn<UT> for DriversLicenseView
impl<UT> LiftReturn<UT> for DriversLicenseView
Sourcetype ReturnType = <DriversLicenseView as Lift<UT>>::FfiType
type ReturnType = <DriversLicenseView as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for DriversLicenseView
impl<UT> Lower<UT> for DriversLicenseView
Sourceimpl<UT> LowerError<UT> for DriversLicenseView
impl<UT> LowerError<UT> for DriversLicenseView
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for DriversLicenseView
impl<UT> LowerReturn<UT> for DriversLicenseView
Sourcetype ReturnType = <DriversLicenseView as Lower<UT>>::FfiType
type ReturnType = <DriversLicenseView as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for DriversLicenseViewwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for DriversLicenseViewwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for DriversLicenseViewwhere
DriversLicenseView: Serialize,
impl OptionIntoWasmAbi for DriversLicenseViewwhere
DriversLicenseView: Serialize,
Sourceimpl PartialEq for DriversLicenseView
impl PartialEq for DriversLicenseView
Sourceimpl RefFromWasmAbi for DriversLicenseViewwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for DriversLicenseViewwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<DriversLicenseView>
type Anchor = SelfOwner<DriversLicenseView>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for DriversLicenseView
impl Serialize for DriversLicenseView
Sourceimpl Tsify for DriversLicenseView
impl Tsify for DriversLicenseView
const DECL: &'static str = "export interface DriversLicenseView {\n firstName: string | undefined;\n middleName: string | undefined;\n lastName: string | undefined;\n dateOfBirth: string | undefined;\n licenseNumber: string | undefined;\n issuingCountry: string | undefined;\n issuingState: string | undefined;\n issueDate: string | undefined;\n expirationDate: string | undefined;\n issuingAuthority: string | undefined;\n licenseClass: string | undefined;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for DriversLicenseView
impl<UT> TypeId<UT> for DriversLicenseView
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorFromWasmAbi for DriversLicenseViewwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for DriversLicenseViewwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for DriversLicenseViewwhere
DriversLicenseView: Serialize,
impl VectorIntoWasmAbi for DriversLicenseViewwhere
DriversLicenseView: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for DriversLicenseView
impl WasmDescribe for DriversLicenseView
impl StructuralPartialEq for DriversLicenseView